#[repr(transparent)]pub struct Ctrl(pub u32);Expand description
Security Attribution Unit Control Register.
Tuple Fields
0: u32Implementations
Sourceimpl Ctrl
impl Ctrl
Sourcepub const fn enable(&self) -> bool
pub const fn enable(&self) -> bool
Enable. Enables the SAU. This bit is RAZ/WI when the Security Extension is implemented without an SAU region.
Sourcepub const fn set_enable(&mut self, val: bool)
pub const fn set_enable(&mut self, val: bool)
Enable. Enables the SAU. This bit is RAZ/WI when the Security Extension is implemented without an SAU region.